%global upstream_name marshmallow
%global commit ea1def94e8dc534a1cd0da4aa6756d25cd2762ca
%global shortcommit %(c=%{commit}; echo ${c:0:7})
%global _docdir  %{_datadir}/doc

Name:           python-%{upstream_name}
Version:        2.2.1
Release:        %mkrel 0.4.git%{shortcommit}
Summary:        Python library for converting complex datatypes to and from primitive types
Group:          Development/Python
License:        MIT
URL:            http://marshmallow.readthedocs.org/
# Using Github instead of PyPI because the PyPI tarballs don't include tests, 
# docs, or examples, and upstream does not want to change that.
# https://github.com/marshmallow-code/marshmallow/issues/201
Source0:        https://github.com/marshmallow-code/marshmallow/archive/%{commit}/%{upstream_name}-%{commit}.tar.gz
# remove dependency on bundled ordered_set
Patch0:         ordered_set.patch
BuildArch:      noarch

# Python 2
BuildRequires:  python2-devel
BuildRequires:  python-setuptools
# for tests
BuildRequires:  python-pytest
BuildRequires:  python-pytz
BuildRequires:  python-dateutil
BuildRequires:  python-ordered-set
BuildRequires:  python-tox
BuildRequires:  python-simplejson

# Python 3
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
# for tests
BuildRequires:  python3-pytest
BuildRequires:  python3-pytz
BuildRequires:  python3-dateutil
BuildRequires:  python3-ordered-set
BuildRequires:  python3-tox
BuildRequires:  python3-simplejson

%description
Marshmallow is a framework-agnostic library for converting complex datatypes, 
such as objects, to and from primitive Python datatypes.

Marshmallow schemas can be used to:
* Validate input data.
* Deserialize input data to app-level objects.
* Serialize app-level objects to primitive Python types. The serialized objects 
  can then be rendered to standard formats such as JSON for use in an HTTP API.

%package -n python2-%{upstream_name}
Summary:        Python 2 library for converting complex datatypes to and from primitive types
Group:          Development/Python
Provides:       python-%{upstream_name} = %{version}-%{release}
Requires:       python-dateutil
Requires:       python-ordered-set

%description -n python2-%{upstream_name}
Marshmallow is a framework-agnostic library for converting complex datatypes, 
such as objects, to and from primitive Python datatypes.

Marshmallow schemas can be used to:
* Validate input data.
* Deserialize input data to app-level objects.
* Serialize app-level objects to primitive Python types. The serialized objects 
  can then be rendered to standard formats such as JSON for use in an HTTP API.

%package -n python2-%{upstream_name}-doc
Summary: Documentation for python2-%{upstream_name}
Group: Development/Python
Provides: python-%{upstream_name}-doc = %{version}-%{release}
BuildArch: noarch

%description -n python2-%{upstream_name}-doc
Documentation for %{name}.

%package -n python3-%{upstream_name}
Summary:        Python 3 library for converting complex datatypes to and from primitive types
Group:          Development/Python
Requires:       python3-dateutil
Requires:       python3-ordered-set

%description -n python3-%{upstream_name}
Marshmallow is a framework-agnostic library for converting complex datatypes, 
such as objects, to and from primitive Python datatypes.

Marshmallow schemas can be used to:
* Validate input data.
* Deserialize input data to app-level objects.
* Serialize app-level objects to primitive Python types. The serialized objects 
  can then be rendered to standard formats such as JSON for use in an HTTP API.

%package -n python3-%{upstream_name}-doc
Summary: Documentation for python3-%{upstream_name}
Group: Development/Python
BuildArch: noarch

%description -n python3-%{upstream_name}-doc
Documentation for %{name}.


%prep
%setup -q -n %{upstream_name}-%{commit}
%patch0

# remove bundled library
# instead of orderedsett we patch code to usu python-ordered-set
# ordereddict.py is used only for compatibility with python2.6,
# which we do not need
rm -f ./marshmallow/ordereddict.py ./marshmallow/orderedset.py


%build
%py2_build
%py3_build

%install
%py2_install
mkdir -p %{buildroot}%{_docdir}/python2-%{upstream_name}
cp -a docs/* examples %{buildroot}%{_docdir}/python2-%{upstream_name}/

%py3_install
mkdir -p %{buildroot}%{_docdir}/python3-%{upstream_name}
cp -a docs/* examples %{buildroot}%{_docdir}/python3-%{upstream_name}/

%check
%{__python2} setup.py test
%{__python3} setup.py test

%files -n python2-%{upstream_name}
%doc CHANGELOG.rst AUTHORS.rst README.rst
%exclude %{_docdir}/python2-%{upstream_name}/*
%license LICENSE
%{python_sitelib}/%{upstream_name}
%{python_sitelib}/%{upstream_name}*.egg-info

%files -n python2-%{upstream_name}-doc
%license LICENSE
%doc %{_docdir}/python2-%{upstream_name}
%exclude %{_docdir}/python2-%{upstream_name}/CHANGELOG.rst
%exclude %{_docdir}/python2-%{upstream_name}/AUTHORS.rst
%exclude %{_docdir}/python2-%{upstream_name}/README.rst
%exclude %{_docdir}/python2-%{upstream_name}/*.pyc
%exclude %{_docdir}/python2-%{upstream_name}/*.pyo
%exclude %{_docdir}/python2-%{upstream_name}/examples/*.pyc
%exclude %{_docdir}/python2-%{upstream_name}/examples/*.pyo

%files -n python3-%{upstream_name}
%doc CHANGELOG.rst AUTHORS.rst README.rst
%exclude %{_docdir}/python3-%{upstream_name}/*
%license LICENSE
%{python3_sitelib}/%{upstream_name}
%{python3_sitelib}/%{upstream_name}*.egg-info

%files -n python3-%{upstream_name}-doc
%license LICENSE
%doc %{_docdir}/python3-%{upstream_name}
%exclude %{_docdir}/python3-%{upstream_name}/CHANGELOG.rst
%exclude %{_docdir}/python3-%{upstream_name}/AUTHORS.rst
%exclude %{_docdir}/python3-%{upstream_name}/README.rst
%exclude %{_docdir}/python3-%{upstream_name}/*.pyc
%exclude %{_docdir}/python3-%{upstream_name}/*.pyo
%exclude %{_docdir}/python3-%{upstream_name}/examples/*.pyc
%exclude %{_docdir}/python3-%{upstream_name}/examples/*.pyo



%changelog
* Sun May 15 2016 ngompa <ngompa> 2.2.1-0.4.gitea1def9.mga6
+ Revision: 1015705
- imported package python-marshmallow

